@@ -33,7 +33,7 @@ class AppRun(object):
 
     def app_run(self, app_name):
         app_file = list(self._apps_path.glob(f'*{app_name}*'))
-        return os.system(f"python {app_file}")
+        return os.system(f"python {app_file[0]}")
 
 
 def cli():
