@@ -8,5 +8,8 @@
 # @Software     : PyCharm
 # @Description  : 
 
+import os
+from .Templates import Templates
 
-from .Templates import Templates
\ No newline at end of file
+get_module_path = lambda path, file=__file__: \
+    os.path.normpath(os.path.join(os.getcwd(), os.path.dirname(file), path))
